"""
    EMIL DiscountService

    The EMIL DiscountService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.discount
from eis.discount.api.vouchers_api import VouchersApi  # noqa: E501


class TestVouchersApi(unittest.TestCase):
    """VouchersApi unit test stubs"""

    def setUp(self):
        self.api = VouchersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_voucher(self):
        """Test case for create_voucher

        Create the Voucher  # noqa: E501
        """
        pass

    def test_delete_voucher(self):
        """Test case for delete_voucher

        Delete the Voucher  # noqa: E501
        """
        pass

    def test_get_voucher(self):
        """Test case for get_voucher

        Retrieve the Voucher  # noqa: E501
        """
        pass

    def test_list_vouchers(self):
        """Test case for list_vouchers

        List Vouchers  # noqa: E501
        """
        pass

    def test_update_voucher(self):
        """Test case for update_voucher

        Update the Voucher  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
