"""
    EMIL DiscountService

    The EMIL DiscountService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.discount
from eis.discount.api.policy_vouchers_api import PolicyVouchersApi  # noqa: E501


class TestPolicyVouchersApi(unittest.TestCase):
    """PolicyVouchersApi unit test stubs"""

    def setUp(self):
        self.api = PolicyVouchersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_charge_policy_voucher(self):
        """Test case for charge_policy_voucher

        Charges the policy voucher.  # noqa: E501
        """
        pass

    def test_check_account_eligibility(self):
        """Test case for check_account_eligibility

        Checks the account eligibility.  # noqa: E501
        """
        pass

    def test_create_policy_voucher(self):
        """Test case for create_policy_voucher

        Create the policy voucher  # noqa: E501
        """
        pass

    def test_delete_policy_voucher(self):
        """Test case for delete_policy_voucher

        Delete the policy voucher  # noqa: E501
        """
        pass

    def test_get_policy_voucher(self):
        """Test case for get_policy_voucher

        Retrieve the policy voucher  # noqa: E501
        """
        pass

    def test_list_policy_vouchers(self):
        """Test case for list_policy_vouchers

        List policy vouchers  # noqa: E501
        """
        pass

    def test_redeem_policy_voucher(self):
        """Test case for redeem_policy_voucher

        Redeems the policy voucher.  # noqa: E501
        """
        pass

    def test_withdraw_policy_voucher(self):
        """Test case for withdraw_policy_voucher

        Withdraws the policy voucher.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
