"""
    EMIL DiscountService

    The EMIL DiscountService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.discount
from eis.discount.model.policy_voucher_class import PolicyVoucherClass
globals()['PolicyVoucherClass'] = PolicyVoucherClass
from eis.discount.model.list_policy_vouchers_response_class import ListPolicyVouchersResponseClass


class TestListPolicyVouchersResponseClass(unittest.TestCase):
    """ListPolicyVouchersResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListPolicyVouchersResponseClass(self):
        """Test ListPolicyVouchersResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListPolicyVouchersResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
