"""
    EMIL DiscountService

    The EMIL DiscountService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.discount
from eis.discount.api.campaigns_api import CampaignsApi  # noqa: E501


class TestCampaignsApi(unittest.TestCase):
    """CampaignsApi unit test stubs"""

    def setUp(self):
        self.api = CampaignsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_campaign(self):
        """Test case for create_campaign

        Create the Campaign  # noqa: E501
        """
        pass

    def test_create_eligible_account(self):
        """Test case for create_eligible_account

        Create the Eligible Account  # noqa: E501
        """
        pass

    def test_delete_campaign(self):
        """Test case for delete_campaign

        Delete the Campaign  # noqa: E501
        """
        pass

    def test_delete_eligible_account(self):
        """Test case for delete_eligible_account

        Delete the Eligible Account  # noqa: E501
        """
        pass

    def test_delete_eligible_accounts(self):
        """Test case for delete_eligible_accounts

        Delete the Eligible Accounts  # noqa: E501
        """
        pass

    def test_get_campaign(self):
        """Test case for get_campaign

        Retrieve the Campaign  # noqa: E501
        """
        pass

    def test_list_campaigns(self):
        """Test case for list_campaigns

        List Campaigns  # noqa: E501
        """
        pass

    def test_list_eligible_accounts(self):
        """Test case for list_eligible_accounts

        List Eligible Accounts  # noqa: E501
        """
        pass

    def test_update_campaign(self):
        """Test case for update_campaign

        Update the Campaign  # noqa: E501
        """
        pass

    def test_update_campaign_status(self):
        """Test case for update_campaign_status

        Updates the status of a campaign.  # noqa: E501
        """
        pass

    def test_upload_eligible_accounts(self):
        """Test case for upload_eligible_accounts

        Uploads the eligible accounts.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
